<?php

namespace Drupal\jwt_path_auth\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\ConfigTarget;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\RedundantEditableConfigNamesTrait;

/**
 * Class ConfigForm.
 */
class PathConfigForm extends ConfigFormBase {
  use RedundantEditableConfigNamesTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'jwt_path_auth_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['help'] = [
      '#markup' => $this->t('Configure path prefixes where a JWT may be used in the query string to authenticate.'),
    ];

    $form['allowed_path_prefixes'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Path Prefixes'),
      '#config_target' => new ConfigTarget(
        'jwt_path_auth.config',
        'allowed_path_prefixes',
        fn(array $value) =>  implode("\n", $value),
        fn(string $value) => explode("\n", $value),
      ),
      '#description' => $this->t('Enter one path prefix value per line.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    $string = $form_state->getValue('allowed_path_prefixes');
    $list = explode("\n", $string);
    $list = array_map('trim', $list);
    $prefix_list = array_filter($list, 'strlen');

    foreach ($prefix_list as $path) {
      if ($path[0] !== '/') {
        $form_state->setErrorByName('allowed_path_prefixes', $this->t('Paths must start with a slash.'));
        return;
      }
    }
    $form_state->setValue('allowed_path_prefixes', implode("\n", $prefix_list));
  }

}
